==> fswiki-3.5.6.tbz: share/fswiki/plugin/bbs/BBSHandler.pm <==
############################################################
#
# Ǽǥץ饰Υϥɥ顣
#
############################################################
package plugin::bbs::BBSHandler;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# ν񤭹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $name    = $cgi->param("name");
	my $subject = $cgi->param("subject");
	my $message = $cgi->param("message");
	my $count   = $cgi->param("count");
	my $page    = $cgi->param("page");
	my $option  = $cgi->param("option");
	
	if($name eq ""){
		$name = "̵̾";
	} else {
		# post_nameȤǥå򥻥åȤ
		my $path   = &Util::cookie_path($wiki);
		my $cookie = $cgi->cookie(-name=>'post_name',-value=>$name,-expires=>'+1M',-path=>$path);
		print "Set-Cookie: ",$cookie->as_string,"\n";
	}
	
	if($subject eq ""){
		$subject = "̵";
	}
	
	if($page eq "" || $count eq ""){
		return $wiki->error("ѥ᡼Ǥ");
	} elsif($message eq ""){
		return $wiki->error("ʸϤƤ");
	}
	
	# եޥåȥץ饰ؤб
	my $format = $wiki->get_edit_format();
	$name    = $wiki->convert_to_fswiki($name   ,$format,1);
	$subject = $wiki->convert_to_fswiki($subject,$format,1);
	$message = $wiki->convert_to_fswiki($message,$format);
	
	my @lines = split(/\n/,$wiki->get_page($page));
	my $flag       = 0;
	my $form_count = 1;
	my $content    = "";
	
	foreach(@lines){
		$content = $content.$_."\n";
		if(/^{{bbs\s*.*}}$/ && $flag==0){
			if($form_count==$count){
				$content .= "!!$subject - $name (".&Util::format_date(time()).")\n".
				            "$message\n";
				
				# no_commentץ
				if($option eq "no_comment"){
					
				# reverse_commentץ
				} elsif($option eq "reverce_comment"){
					$content .= "{{comment reverse}}\n";
				# ǥե
				} else {
					$content .= "{{comment}}\n";
				}
				$flag = 1;
				
			} else {
				$form_count++;
			}
		}
	}
	if($flag==1){
		$wiki->save_page($page,$content);
	}
	
	# Υڡ˥쥯Ȥ
	$wiki->redirect($page);
}

1;

==> fswiki-3.6.2_1.tbz: share/fswiki/plugin/bbs/BBSHandler.pm <==
############################################################
#
# Ǽǥץ饰Υϥɥ顣
#
############################################################
package plugin::bbs::BBSHandler;
use strict;
#===========================================================
# 󥹥ȥ饯
#===========================================================
sub new {
	my $class = shift;
	my $self = {};
	return bless $self,$class;
}

#===========================================================
# ν񤭹
#===========================================================
sub do_action {
	my $self = shift;
	my $wiki = shift;
	my $cgi  = $wiki->get_CGI;
	
	my $name    = $cgi->param("name");
	my $subject = $cgi->param("subject");
	my $message = $cgi->param("message");
	my $count   = $cgi->param("count");
	my $page    = $cgi->param("page");
	my $option  = $cgi->param("option");
	
	if($name eq ""){
		$name = "̵̾";
	} else {
		# post_nameȤǥå򥻥åȤ
		my $path   = &Util::cookie_path($wiki);
		my $cookie = $cgi->cookie(-name=>'post_name',-value=>$name,-expires=>'+1M',-path=>$path);
		print "Set-Cookie: ",$cookie->as_string,"\n";
	}
	
	if($subject eq ""){
		$subject = "̵";
	}
	
	if($page eq "" || $count eq ""){
		return $wiki->error("ѥ᡼Ǥ");
	} elsif($message eq ""){
		return $wiki->error("ʸϤƤ");
	}
	
	# եޥåȥץ饰ؤб
	my $format = $wiki->get_edit_format();
	$name    = $wiki->convert_to_fswiki($name   ,$format,1);
	$subject = $wiki->convert_to_fswiki($subject,$format,1);
	$message = $wiki->convert_to_fswiki($message,$format);
	
	my @lines = split(/\n/,$wiki->get_page($page));
	my $flag       = 0;
	my $form_count = 1;
	my $content    = "";
	
	foreach(@lines){
		$content = $content.$_."\n";
		if(/^{{bbs\s*.*}}$/ && $flag==0){
			if($form_count==$count){
				$content .= "!!$subject - $name (".&Util::format_date(time()).")\n".
				            "$message\n";
				
				# no_commentץ
				if($option eq "no_comment"){
					
				# reverse_commentץ
				} elsif($option eq "reverse_comment"){
					$content .= "{{comment reverse}}\n";
				# ǥե
				} else {
					$content .= "{{comment}}\n";
				}
				$flag = 1;
				
			} else {
				$form_count++;
			}
		}
	}
	if($flag==1){
		$wiki->save_page($page,$content);
	}
	
	# Υڡ˥쥯Ȥ
	$wiki->redirect($page);
}

1;
